pub enum ThresholdMode {
GreaterThan,
LessThan,
}Expand description
Touchpad threshold type.
Variants
GreaterThan
Pad is considered touched if value is greater than threshold.
LessThan
Pad is considered touched if value is less than threshold.